@@ -71,7 +71,7 @@ args_html = '''
 class TestEmailService(unittest.TestCase):
 
     def setUp(self) -> None:
-        self.email_config = Mock()
+        self.email_config = Mock(disable_smtp_auth=False)
         self.logger = Mock()
         self.email_service = EmailService(self.email_config, self.logger)
 
@@ -285,6 +285,25 @@ class TestEmailService(unittest.TestCase):
         mock_smtp.return_value.sendmail.assert_called_once()
         mock_smtp.return_value.close.assert_called_once()
 
+    @patch('cloudshell.email.email_service.MIMEMultipart')
+    @patch('smtplib.SMTP')
+    def test_send_with_embedded_header(self, mock_smtp, msg_mock_class):
+        # arrange
+        msg_mock = MagicMock()
+        msg_mock_class.return_value = msg_mock
+        email = 'aaa@bbb.com'
+        self.email_service._email_config.from_address = 'aaa@bbb.com'
+        subject = 'embedded\nheader: attack'
+
+        mock_smtp.return_value = Mock()
+
+        # act
+        self.email_service._send([email], subject, arg_html, [email])
+
+        # assert
+        subject_modified = next(filter(lambda x: x.args[0] == "Subject", msg_mock.mock_calls), None).args[1]
+        self.assertEqual(subject_modified, 'embedded header: attack')
+
     @patch('smtplib.SMTP')
     def test_send_smtprecipientsrefused(self, mock_smtp):
         # arrange
@@ -482,6 +501,17 @@ class TestEmailService(unittest.TestCase):
             'No SSL support included in this Python.'
         )
 
+    @patch('smtplib.SMTP')
+    def test_validate_email_config_disable_smtp_auth(self, mock_smtp):
+        # arrange
+        smtp_obj = Mock()
+        self.email_service._email_config.disable_smtp_auth = True
+        mock_smtp.return_value = smtp_obj
+        # act
+        self.email_service.validate_email_config()
+        # assert
+        assert not mock_smtp.return_value.login.called
+
     def test_send_error_email_raise_error_no_api(self):
         with self.assertRaisesRegex(ValueError, "CloudShell Automation API is required"):
             self.email_service.send_error_email(Mock(), Mock())
